@@ -1,15 +1,12 @@
 package HTTP::OAI::Metadata::METS;
 
-use strict;
-use warnings;
-
-use HTTP::OAI::Metadata;
-use vars qw(@ISA);
-@ISA = qw(HTTP::OAI::Metadata);
-
 use XML::LibXML;
 use XML::LibXML::XPathContext;
 
+@ISA = qw( HTTP::OAI::Metadata );
+
+use strict;
+
 sub new {
 	my $class = shift;
 	my $self = $class->SUPER::new(@_);
@@ -20,6 +17,7 @@ sub new {
 sub _xc
 {
 	my $xc = XML::LibXML::XPathContext->new( @_ );
+	$xc->registerNs( 'oai_dc', HTTP::OAI::OAI_NS );
 	$xc->registerNs( 'mets', 'http://www.loc.gov/METS/' );
 	$xc->registerNs( 'xlink', 'http://www.w3.org/1999/xlink' );
 	return $xc;
@@ -33,7 +31,7 @@ sub files
 	my $xc = _xc($dom);
 
 	my @files;
-	foreach my $file ($xc->findnodes( '//mets:file' ))
+	foreach my $file ($xc->findnodes( '*//mets:file' ))
 	{
 		my $f = {};
 		foreach my $attr ($file->attributes)
