@@ -1,8 +1,11 @@
 package HTTP::OAI::Metadata::OAI_Identifier;
 
+use strict;
+use warnings;
+
+use Carp;
 use XML::LibXML;
 use HTTP::OAI::Metadata;
-use Carp;
 
 use vars qw( @ISA );
 @ISA = qw( HTTP::OAI::Metadata );
@@ -16,10 +19,10 @@ sub new {
 	$root->setAttribute('xmlns:xsi','http://www.w3.org/2001/XMLSchema-instance');
 	$root->setAttribute('xsi:schemaLocation','http://www.openarchives.org/OAI/2.0/oai-identifier http://www.openarchives.org/OAI/2.0/oai-identifier.xsd');
 	for(qw( scheme repositoryIdentifier delimiter sampleIdentifier )) {
-		croak "Required argument $_ is undefined" unless defined($args{$_});
+		Carp::croak "Required argument $_ is undefined" unless defined($args{$_});
 		$root->appendChild($dom->createElement($_))->appendChild($dom->createTextNode($args{$_}));
 	}
-	$self->dom($root);
+	$self->dom($dom);
 	$self;
 }
 
