@@ -1,57 +1,40 @@
 package HTTP::OAI::ResumptionToken;
 
+@ISA = qw( HTTP::OAI::MemberMixin XML::SAX::Base );
+
 use strict;
-use warnings;
-
-use HTTP::OAI::SAXHandler qw/ :SAX /;
-
-use vars qw( @ISA );
-@ISA = qw( HTTP::OAI::Encapsulation );
 
 use overload "bool" => \&not_empty;
 
-sub new {
-	my ($class,%args) = @_;
-	my $self = $class->SUPER::new(%args);
-
-	$self->resumptionToken($args{resumptionToken}) unless $self->resumptionToken;
-	$self->expirationDate($args{expirationDate}) unless $self->expirationDate;
-	$self->completeListSize($args{completeListSize}) unless $self->completeListSize;
-	$self->cursor($args{cursor}) unless $self->cursor;
-
-	$self;
-}
-
 sub resumptionToken { shift->_elem('resumptionToken',@_) }
-sub expirationDate { shift->_attr('expirationDate',@_) }
-sub completeListSize { shift->_attr('completeListSize',@_) }
-sub cursor { shift->_attr('cursor',@_) }
+sub expirationDate { shift->_elem('expirationDate',@_) }
+sub completeListSize { shift->_elem('completeListSize',@_) }
+sub cursor { shift->_elem('cursor',@_) }
 
 sub not_empty { defined($_[0]->resumptionToken) and length($_[0]->resumptionToken) > 0 }
 sub is_empty { !not_empty(@_) }
 
 sub generate {
-	my ($self) = @_;
-	return unless (my $handler = $self->get_handler);
-	my $attr;
-	while(my ($key,$value) = each %{$self->_attr}) {
-		$attr->{"{}$key"} = {'Name'=>$key,'LocalName'=>$key,'Value'=>$value,'Prefix'=>'','NamespaceURI'=>'http://www.openarchives.org/OAI/2.0/'};
-	}
-	g_data_element($handler,'http://www.openarchives.org/OAI/2.0/','resumptionToken',$attr,$self->resumptionToken);
+	my( $self, $driver ) = @_;
+
+	$driver->data_element( 'resumptionToken', $self->resumptionToken,
+		expirationDate => scalar($self->expirationDate),
+		completeListSize => scalar($self->completeListSize),
+		cursor => scalar($self->cursor),
+	);
 }
 
 sub end_element {
 	my ($self,$hash) = @_;
 	$self->SUPER::end_element($hash);
-	if( lc($hash->{Name}) eq 'resumptiontoken' ) {
-		my $attr = $hash->{Attributes};
+	if( lc($hash->{LocalName}) eq 'resumptiontoken' ) {
 		$self->resumptionToken($hash->{Text});
 
+		my $attr = $hash->{Attributes};
 		$self->expirationDate($attr->{'{}expirationDate'}->{'Value'});
 		$self->completeListSize($attr->{'{}completeListSize'}->{'Value'});
 		$self->cursor($attr->{'{}cursor'}->{'Value'});
 	}
-#warn "Got RT: $hash->{Text}";
 }
 
 1;
